==> flink-table-common-1.12.0-sources.jar: org/apache/flink/table/factories/SerializationSchemaFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.factories;

import org.apache.flink.annotation.PublicEvolving;
import org.apache.flink.api.common.serialization.SerializationSchema;

import java.util.Map;

/**
 * Factory for creating configured instances of {@link SerializationSchema}.
 *
 * @param <T> record type that the format produces or consumes.
 */
@PublicEvolving
public interface SerializationSchemaFactory<T> extends TableFormatFactory<T> {

	/**
	 * Creates and configures a [[SerializationSchema]] using the given properties.
	 *
	 * @param properties normalized properties describing the format
	 * @return the configured serialization schema or null if the factory cannot provide an
	 *         instance of this class
	 */
	SerializationSchema<T> createSerializationSchema(Map<String, String> properties);

}

==> flink-table-common-1.15.0-sources.jar: org/apache/flink/table/factories/SerializationSchemaFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.factories;

import org.apache.flink.annotation.PublicEvolving;
import org.apache.flink.api.common.serialization.SerializationSchema;

import java.util.Map;

/**
 * Factory for creating configured instances of {@link SerializationSchema}.
 *
 * @param <T> record type that the format produces or consumes.
 * @deprecated This interface has been replaced by {@link SerializationFormatFactory}, used in the
 *     new sink/source stack. See FLIP-95 for more information.
 */
@Deprecated
@PublicEvolving
public interface SerializationSchemaFactory<T> extends TableFormatFactory<T> {

    /**
     * Creates and configures a [[SerializationSchema]] using the given properties.
     *
     * @param properties normalized properties describing the format
     * @return the configured serialization schema or null if the factory cannot provide an instance
     *     of this class
     */
    SerializationSchema<T> createSerializationSchema(Map<String, String> properties);
}
